import { SharePointQueryable, SharePointQueryableCollection, SharePointQueryableInstance } from "./sharepointqueryable";
import { SharePointQueryableShareableFolder } from "./sharepointqueryableshareable";
import { Files } from "./files";
import { TypedHash } from "../collections/collections";
import { Item } from "./items";
/**
 * Describes a collection of Folder objects
 *
 */
export declare class Folders extends SharePointQueryableCollection {
    /**
     * Creates a new instance of the Folders class
     *
     * @param baseUrl The url or SharePointQueryable which forms the parent of this fields collection
     */
    constructor(baseUrl: string | SharePointQueryable, path?: string);
    /**
     * Gets a folder by folder name
     *
     */
    getByName(name: string): Folder;
    /**
     * Adds a new folder to the current folder (relative) or any folder (absolute)
     *
     * @param url The relative or absolute url where the new folder will be created. Urls starting with a forward slash are absolute.
     * @returns The new Folder and the raw response.
     */
    add(url: string): Promise<FolderAddResult>;
}
/**
 * Describes a single Folder instance
 *
 */
export declare class Folder extends SharePointQueryableShareableFolder {
    /**
     * Specifies the sequence in which content types are displayed.
     *
     */
    readonly contentTypeOrder: SharePointQueryableCollection;
    /**
     * Gets this folder's files
     *
     */
    readonly files: Files;
    /**
     * Gets this folder's sub folders
     *
     */
    readonly folders: Folders;
    /**
     * Gets this folder's list item field values
     *
     */
    readonly listItemAllFields: SharePointQueryableCollection;
    /**
     * Gets the parent folder, if available
     *
     */
    readonly parentFolder: Folder;
    /**
     * Gets this folder's properties
     *
     */
    readonly properties: SharePointQueryableInstance;
    /**
     * Gets this folder's server relative url
     *
     */
    readonly serverRelativeUrl: SharePointQueryable;
    /**
     * Gets a value that specifies the content type order.
     *
     */
    readonly uniqueContentTypeOrder: SharePointQueryableCollection;
    update(properties: TypedHash<string | number | boolean>): Promise<FolderUpdateResult>;
    /**
    * Delete this folder
    *
    * @param eTag Value used in the IF-Match header, by default "*"
    */
    delete(eTag?: string): Promise<void>;
    /**
     * Moves the folder to the Recycle Bin and returns the identifier of the new Recycle Bin item.
     */
    recycle(): Promise<string>;
    /**
     * Gets the associated list item for this folder, loading the default properties
     */
    getItem<T>(...selects: string[]): Promise<Item & T>;
}
export interface FolderAddResult {
    folder: Folder;
    data: any;
}
export interface FolderUpdateResult {
    folder: Folder;
    data: any;
}
