import { SharePointQueryable } from "./sharepointqueryable";
import { EmailProperties } from "./types";
import { ODataBatch } from "./batch";
import { ICachingOptions } from "../odata/caching";
import { File } from "./files";
import { PrincipalInfo, PrincipalType, PrincipalSource, WikiPageCreationInformation } from "./types";
/**
 * Public interface for the utility methods to limit SharePointQueryable method exposure
 */
export interface UtilityMethods {
    usingCaching(options?: ICachingOptions): this;
    inBatch(batch: ODataBatch): this;
    sendEmail(props: EmailProperties): Promise<void>;
    getCurrentUserEmailAddresses(): Promise<string>;
    resolvePrincipal(email: string, scopes: PrincipalType, sources: PrincipalSource, inputIsEmailOnly: boolean, addToUserInfoList: boolean, matchUserInfoList?: boolean): Promise<PrincipalInfo>;
    searchPrincipals(input: string, scopes: PrincipalType, sources: PrincipalSource, groupName: string, maxCount: number): Promise<PrincipalInfo[]>;
    createEmailBodyForInvitation(pageAddress: string): Promise<string>;
    expandGroupsToPrincipals(inputs: string[], maxCount?: number): Promise<PrincipalInfo[]>;
    createWikiPage(info: WikiPageCreationInformation): Promise<CreateWikiPageResult>;
}
/**
 * Allows for calling of the static SP.Utilities.Utility methods by supplying the method name
 */
export declare class UtilityMethod extends SharePointQueryable implements UtilityMethods {
    private static getBaseUrl(candidate);
    /**
     * Creates a new instance of the Utility method class
     *
     * @param baseUrl The parent url provider
     * @param methodName The static method name to call on the utility class
     */
    constructor(baseUrl: string | SharePointQueryable, methodName: string);
    excute<T>(props: any): Promise<T>;
    /**
     * Sends an email based on the supplied properties
     *
     * @param props The properties of the email to send
     */
    sendEmail(props: EmailProperties): Promise<void>;
    getCurrentUserEmailAddresses(): Promise<string>;
    resolvePrincipal(input: string, scopes: PrincipalType, sources: PrincipalSource, inputIsEmailOnly: boolean, addToUserInfoList: boolean, matchUserInfoList?: boolean): Promise<PrincipalInfo>;
    searchPrincipals(input: string, scopes: PrincipalType, sources: PrincipalSource, groupName: string, maxCount: number): Promise<PrincipalInfo[]>;
    createEmailBodyForInvitation(pageAddress: string): Promise<string>;
    expandGroupsToPrincipals(inputs: string[], maxCount?: number): Promise<PrincipalInfo[]>;
    createWikiPage(info: WikiPageCreationInformation): Promise<CreateWikiPageResult>;
}
export interface CreateWikiPageResult {
    data: any;
    file: File;
}
